@@ -5,17 +5,22 @@
 #undef LIL_ENDIAN
 #endif
 #define LIL_ENDIAN 1
-
-#define DEBUGGER 1
-#ifdef PREFIX
-#undef PREFIX
-#endif
-#define PREFIX "/usr/local"
-
-#define R2_VERSION "0.8.1"
-#define HAVE_LIB_MAGIC 0
-#define HAVE_LIB_SSL 1
-
 #define CPU_ENDIAN 0
 
+#define DEBUGGER 1
+
+#if __WIN32__ || __CYGWIN__ || MINGW32
+#define R2_PREFIX "."
+#define R2_LIBDIR "./lib"
+#else
+#define R2_PREFIX "/usr/local"
+#define R2_LIBDIR "/usr/local/lib"
+#endif
+
+#define R2_VERSION "0.8.8"
+#define HAVE_LIB_MAGIC 0
+#define USE_LIB_MAGIC 0
+#define HAVE_LIB_SSL 1
+
+
 #endif
